@@ -27,6 +27,11 @@
 #include <thai/thwchar.h>
 #include <thai/thbrk.h>
 
+/* TODO
+ * LibThai 0.1.23 claims to be thread-safe.
+ * Check that and avoid locking?
+ * http://linux.thai.net/node/286
+ */
 G_LOCK_DEFINE_STATIC (th_brk);
 
 /*
@@ -78,10 +83,15 @@ break_thai (const char          *text,
   /* find line break positions */
 
   G_LOCK (th_brk);
-  len = th_brk (tis_text, brk_pnts, len);
+  len = th_brk (tis_text, brk_pnts, cnt);
   G_UNLOCK (th_brk);
   for (cnt = 0; cnt < len; cnt++)
+    if (attrs[brk_pnts[cnt]].is_char_break)
     {
+      /* Only allow additional line breaks if line-breaking is NOT
+       * prohibited. (The alternative would be to set is_char_break to
+       * TRUE as well.  NOT setting it will break invariants that any
+       * line break opportunity is also a char break opportunity. */
       attrs[brk_pnts[cnt]].is_line_break = TRUE;
       attrs[brk_pnts[cnt]].is_word_start = TRUE;
       attrs[brk_pnts[cnt]].is_word_end = TRUE;
